@@ -81,6 +81,9 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
             break;
         }
     }
+    
+    // required for X11
+    app.setWindowIcon(QIcon::fromTheme(QStringLiteral("org.kde.krecorder")));
 
     return app.exec();
 }
